@@ -30,6 +30,7 @@
 #include "groupdefinition.h"
 #include "windowparameterdefinition.h"
 #include "booleanparameterdefinition.h"
+#include "ifactionparameterdefinition.h"
 
 #include <limits>
 
@@ -50,6 +51,7 @@ namespace Actions
 		: ActionDefinition(pack)
 		{
 			translateItems("FindImageInstance::sources", FindImageInstance::sources);
+            translateItems("FindImageInstance::methods", FindImageInstance::methods);
 
 			ActionTools::ListParameterDefinition *source = new ActionTools::ListParameterDefinition(ActionTools::Name("source", tr("Source")), this);
 			source->setTooltip(tr("The source of the image to search in"));
@@ -57,15 +59,19 @@ namespace Actions
 			source->setDefaultValue(FindImageInstance::sources.second.at(FindImageInstance::ScreenshotSource));
 			addElement(source);
 
-			ActionTools::GroupDefinition *windowNameGroup = new ActionTools::GroupDefinition(this);
-			windowNameGroup->setMasterList(source);
-			windowNameGroup->setMasterValues(QStringList() << FindImageInstance::sources.first.at(FindImageInstance::WindowSource));
+            ActionTools::GroupDefinition *windowGroup = new ActionTools::GroupDefinition(this);
+            windowGroup->setMasterList(source);
+            windowGroup->setMasterValues(QStringList() << FindImageInstance::sources.first.at(FindImageInstance::WindowSource));
 
 			ActionTools::WindowParameterDefinition *windowName = new ActionTools::WindowParameterDefinition(ActionTools::Name("windowName", tr("Window name")), this);
 			windowName->setTooltip(tr("The title of the window to search in, you can use wildcards like * (any number of characters) or ? (one character) here"));
-			windowNameGroup->addMember(windowName);
+            windowGroup->addMember(windowName);
 
-			addElement(windowNameGroup);
+            ActionTools::BooleanParameterDefinition *relativePosition = new ActionTools::BooleanParameterDefinition(ActionTools::Name("windowRelativePosition", tr("Window relative position")), this);
+            relativePosition->setTooltip(tr("The position is relative to the window\nIf this parameter is set to false (not checked) then the position is absolute"));
+            windowGroup->addMember(relativePosition);
+
+            addElement(windowGroup);
 
 			ActionTools::GroupDefinition *imageToSearchInGroup = new ActionTools::GroupDefinition(this);
 			imageToSearchInGroup->setMasterList(source);
@@ -87,19 +93,25 @@ namespace Actions
 			imageToFind->setFilter(tr("Image files (*.bmp *.gif *.jpg *.jpeg *.mng *.png *.pbm *.pgm *.ppm *.tiff *.xbm *.xpm *.svg)\nAll files (*.*)"));
 			addElement(imageToFind);
 
+            ActionTools::IfActionParameterDefinition *ifFound = new ActionTools::IfActionParameterDefinition(ActionTools::Name("ifFound", tr("If found")), this);
+            ifFound->setTooltip(tr("What to do if the image is found"));
+            ifFound->setAllowWait(true);
+            addElement(ifFound);
+
+            ActionTools::IfActionParameterDefinition *ifNotFound = new ActionTools::IfActionParameterDefinition(ActionTools::Name("ifNotFound", tr("If not found")), this);
+            ifNotFound->setTooltip(tr("What to do if the image is not found"));
+            ifNotFound->setAllowWait(true);
+            addElement(ifNotFound);
+
 			ActionTools::VariableParameterDefinition *position = new ActionTools::VariableParameterDefinition(ActionTools::Name("position", tr("Position")), this);
 			position->setTooltip(tr("The name of the variable where to store the coordinates of the center of the found image"));
 			addElement(position);
 
-			ActionTools::GroupDefinition *relativePositionGroup = new ActionTools::GroupDefinition(this);
-			relativePositionGroup->setMasterList(source);
-			relativePositionGroup->setMasterValues(QStringList() << FindImageInstance::sources.first.at(FindImageInstance::WindowSource));
-
-			ActionTools::BooleanParameterDefinition *relativePosition = new ActionTools::BooleanParameterDefinition(ActionTools::Name("windowRelativePosition", tr("Window relative position")), this);
-			relativePosition->setTooltip(tr("The position is relative to the window\nIf this parameter is set to false (not checked) then the position is absolute"));
-			relativePositionGroup->addMember(relativePosition);
-
-			addElement(relativePositionGroup, 1);
+            ActionTools::ListParameterDefinition *method = new ActionTools::ListParameterDefinition(ActionTools::Name("method", tr("Method")), this);
+            method->setTooltip(tr("The matching method to use"));
+            method->setItems(FindImageInstance::methods);
+            method->setDefaultValue(FindImageInstance::methods.second.at(FindImageInstance::CorrelationCoefficientMethod));
+            addElement(method, 1);
 
 			ActionTools::NumberParameterDefinition *confidenceMinimum = new ActionTools::NumberParameterDefinition(ActionTools::Name("confidenceMinimum", tr("Confidence minimum")), this);
 			confidenceMinimum->setTooltip(tr("The minimum confidence percentage required to select a possible matching image"));
@@ -115,8 +127,8 @@ namespace Actions
 			maximumMatches->setDefaultValue(1);
 			addElement(maximumMatches, 1);
 
-			ActionTools::NumberParameterDefinition *downPyramidCount = new ActionTools::NumberParameterDefinition(ActionTools::Name("downPyramidCount", tr("Down pyramid count")), this);
-			downPyramidCount->setTooltip(tr("The number of down pyramids to use\nA pyramid is a subdivision of the image used to accelerate the search\nEnter 1 here if the searched image is not very different from the source image"));
+			ActionTools::NumberParameterDefinition *downPyramidCount = new ActionTools::NumberParameterDefinition(ActionTools::Name("downPyramidCount", tr("Downsampling")), this);
+			downPyramidCount->setTooltip(tr("The downsampling value to use\nDownsampling is used to accelerate the search when using large images"));
 			downPyramidCount->setMinimum(1);
 			downPyramidCount->setMaximum(std::numeric_limits<int>::max());
 			downPyramidCount->setDefaultValue(1);
@@ -129,22 +141,36 @@ namespace Actions
 			searchExpansion->setDefaultValue(15);
 			addElement(searchExpansion, 1);
 
+            ActionTools::NumberParameterDefinition *searchDelay = new ActionTools::NumberParameterDefinition(ActionTools::Name("searchDelay", tr("Delay between two searches when waiting")), this);
+            searchDelay->setTooltip(tr("The delay between two searches"));
+            searchDelay->setMinimum(0);
+            searchDelay->setMaximum(std::numeric_limits<int>::max());
+            searchDelay->setDefaultValue(100);
+            searchDelay->setSuffix(tr(" ms", "milliseconds"));
+            addElement(searchDelay, 1);
+
+            ActionTools::VariableParameterDefinition *confidence = new ActionTools::VariableParameterDefinition(ActionTools::Name("confidence", tr("Confidence")), this);
+            confidence->setTooltip(tr("The name of the variable where to store the confidence value found image"));
+            addElement(confidence, 1);
+
 			addException(FindImageInstance::ErrorWhileSearchingException, tr("Error while searching"));
-			addException(FindImageInstance::CannotFindTheImageException, tr("Cannot find the image"));
 		}
 
 		QString name() const													{ return QObject::tr("Find image"); }
 		QString id() const														{ return "ActionFindImage"; }
 		ActionTools::Flag flags() const											{ return ActionDefinition::flags() | ActionTools::Official; }
 		QString description() const												{ return QObject::tr("Finds an image on the screen, on a window or on another image"); }
+        Tools::Version version() const                                          { return Tools::Version(1, 1, 0); }
 		ActionTools::ActionInstance *newActionInstance() const					{ return new FindImageInstance(this); }
 		ActionTools::ActionCategory category() const							{ return ActionTools::System; }
 		QPixmap icon() const													{ return QPixmap(":/icons/findimage.png"); }
 		QStringList tabs() const												{ return ActionDefinition::StandardTabs; }
 
+        void updateAction(ActionTools::ActionInstance *actionInstance, const Tools::Version &version) const;
+
 	private:
-		Q_DISABLE_COPY(FindImageDefinition)
-	};
+        Q_DISABLE_COPY(FindImageDefinition)
+    };
 }
 
 #endif // FINDIMAGEDEFINITION_H
