@@ -21,10 +21,13 @@
 #include "script.h"
 #include "actioninstance.h"
 #include "actiondefinition.h"
+#include "elementdefinition.h"
 #include "actionfactory.h"
 #include "parameter.h"
 #include "subparameter.h"
 #include "messagehandler.h"
+#include "variableparameterdefinition.h"
+#include "groupdefinition.h"
 
 #include <QIODevice>
 #include <QFile>
@@ -35,6 +38,8 @@
 
 namespace ActionTools
 {
+    const QRegExp Script::CodeVariableDeclarationRegExp("^[ \t]*var ([A-Za-z_][A-Za-z0-9_]*)", Qt::CaseSensitive, QRegExp::RegExp2);
+
 	Script::Script(ActionFactory *actionFactory, QObject *parent)
 		: QObject(parent),
 		mActionFactory(actionFactory),
@@ -370,7 +375,7 @@ namespace ActionTools
 						mOs = attributes.value("os").toString();
 
 						if(mScriptVersion > scriptVersion)
-							return ReadBadScriptVersion;
+							return ReadInvalidScriptVersion;
 					}
 				}
 
@@ -378,7 +383,7 @@ namespace ActionTools
 				mLine = messageHandler.line();
 				mColumn = messageHandler.column();
 
-				return ReadBadSchema;
+				return ReadInvalidSchema;
 			}
 		}
 
@@ -392,6 +397,8 @@ namespace ActionTools
 		Tools::HighResolutionTimer timer2("Reading content");
 #endif
 
+        QHash<ActionDefinition *, Tools::Version> updatableActionDefinitions;
+
 		QXmlStreamReader stream(device);
 		while(!stream.atEnd() && !stream.hasError())
 		{
@@ -412,7 +419,7 @@ namespace ActionTools
 				mOs = attributes.value("os").toString();
 
 				if(mScriptVersion > scriptVersion)
-					return ReadBadScriptVersion;
+					return ReadInvalidScriptVersion;
 			}
 			else if(stream.name() == "actions")
 			{
@@ -425,11 +432,13 @@ namespace ActionTools
 
 					const QXmlStreamAttributes &attributes = stream.attributes();
 					QString name = attributes.value("name").toString();
-					//TODO : Do something with the action version
+                    Tools::Version version(attributes.value("version").toString());
 
 					ActionDefinition *actionDefinition = mActionFactory->actionDefinition(name);
 					if(!actionDefinition)
 						mMissingActions << name;
+                    else if(actionDefinition->version() > version)
+                        updatableActionDefinitions[actionDefinition] = version;
 				}
 			}
 			else if(stream.name() == "parameters")
@@ -524,9 +533,18 @@ namespace ActionTools
 						}
 					}
 
+                    //Set default values, will be overwritten afterwards, but this is done to make sure we have valid parameters everywhere
+                    foreach(ElementDefinition *element, actionInstance->definition()->elements())
+                        element->setDefaultValues(actionInstance);
+
 					actionInstance->setLabel(label);
 					actionInstance->setComment(comment);
-					actionInstance->setParametersData(parametersData);
+
+                    ParametersData defaultParametersData = actionInstance->parametersData();
+                    foreach(const QString &parameterKey, parametersData.keys())
+                        defaultParametersData[parameterKey] = parametersData.value(parameterKey);
+
+                    actionInstance->setParametersData(defaultParametersData);
 					actionInstance->setColor(color);
 					actionInstance->setEnabled(enabled);
 					actionInstance->setExceptionActionInstances(exceptionActionsHash);
@@ -539,6 +557,15 @@ namespace ActionTools
 			}
 		}
 
+        foreach(ActionDefinition *actionDefinition, updatableActionDefinitions.keys())
+        {
+            foreach(ActionInstance *actionInstance, mActionInstances)
+            {
+                if(actionInstance->definition() == actionDefinition)
+                    actionDefinition->updateAction(actionInstance, updatableActionDefinitions.value(actionDefinition));
+            }
+        }
+
 		return ReadSuccess;
 	}
 
@@ -616,6 +643,110 @@ namespace ActionTools
 				back << actionInstance->label();
 		}
 
-		return back;
-	}
+        return back;
+    }
+
+    QSet<QString> Script::findVariables(ActionInstance *actionInstance, ActionInstance *excludedActionInstance) const
+    {
+        QSet<QString> back;
+
+        if(actionInstance)
+        {
+            if(actionInstance != excludedActionInstance)
+                findVariablesInAction(actionInstance, back);
+        }
+        else
+        {
+            foreach(const ScriptParameter &scriptParameter, mParameters)
+            {
+                if(!scriptParameter.name().isEmpty())
+                    back << scriptParameter.name();
+            }
+
+            foreach(ActionInstance *currentActionInstance, mActionInstances)
+            {
+                if(currentActionInstance != excludedActionInstance)
+                    findVariablesInAction(currentActionInstance, back);
+            }
+        }
+
+        return back;
+    }
+
+    void Script::parametersFromDefinition(QSet<QString> &variables, const ActionInstance *actionInstance, const ElementDefinition *elementDefinition) const
+    {
+        const Parameter &parameter = actionInstance->parameter(elementDefinition->name().original());
+        const SubParameterHash &subParameters = parameter.subParameters();
+
+        SubParameterHash::ConstIterator it = subParameters.constBegin();
+        for(;it != subParameters.constEnd();++it)
+        {
+            const SubParameter &subParameter = it.value();
+
+            if(subParameter.isCode())
+            {
+                //Add every variable in any parameter type that is in code mode
+                const QString &code = subParameter.value().toString();
+
+                foreach(const QString &codeLine, code.split(QRegExp("[\n\r;]"), QString::SkipEmptyParts))
+                {
+                    int position = 0;
+
+                    while((position = CodeVariableDeclarationRegExp.indexIn(codeLine, position)) != -1)
+                    {
+                        QString foundVariableName = CodeVariableDeclarationRegExp.cap(1);
+
+                        position += CodeVariableDeclarationRegExp.cap(1).length();
+
+                        if(!foundVariableName.isEmpty())
+                            variables << foundVariableName;
+                    }
+                }
+            }
+            else
+            {
+                //Add every variable in a variable parameter that is not in code mode
+                if(qobject_cast<const VariableParameterDefinition *>(elementDefinition))
+                {
+                    const QString &foundVariableName = subParameter.value().toString();
+
+                    if(!foundVariableName.isEmpty())
+                        variables << foundVariableName;
+
+                    continue;
+                }
+
+                //Add every variable in any parameter type that is not in code mode
+                const QString &text = subParameter.value().toString();
+
+                int position = 0;
+
+                while((position = ActionInstance::VariableRegExp.indexIn(text, position)) != -1)
+                {
+                    QString foundVariableName = ActionInstance::VariableRegExp.cap(2);
+
+                    position += ActionInstance::VariableRegExp.cap(0).length();
+
+                    if(!foundVariableName.isEmpty())
+                        variables << foundVariableName;
+                }
+            }
+        }
+    }
+
+    void Script::findVariablesInAction(ActionInstance *actionInstance, QSet<QString> &result) const
+    {
+        const ActionDefinition *actionDefinition = actionInstance->definition();
+
+        foreach(const ElementDefinition *elementDefinition, actionDefinition->elements())
+        {
+            if(const GroupDefinition *groupDefinition = qobject_cast<const GroupDefinition *>(elementDefinition))
+            {
+                foreach(const ParameterDefinition *parameterDefinition, groupDefinition->members())
+                    parametersFromDefinition(result, actionInstance, parameterDefinition);
+            }
+            else
+                parametersFromDefinition(result, actionInstance, elementDefinition);
+        }
+    }
 }
