@@ -41,6 +41,11 @@
         <source>The screen position where to simulate a mouse click</source>
         <translation>La position à l&apos;écran où simuler le clic de souris</translation>
     </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="82"/>
+        <source>The offset to apply to the click position</source>
+        <translation>Le décalage à appliquer à la position du clic</translation>
+    </message>
     <message>
         <source>Click action</source>
         <translation type="obsolete">Action de clic</translation>
@@ -57,11 +62,20 @@
     </message>
     <message>
         <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="81"/>
+        <source>Offset</source>
+        <translation>Décalage</translation>
+    </message>
+    <message>
+        <source>The offset to apply at the click position</source>
+        <translation type="obsolete">Le décalage à appliquer à la position du clic</translation>
+    </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="85"/>
         <source>Send input failure</source>
         <translation>Échec de la simulation</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="82"/>
+        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="86"/>
         <source>Invalid action</source>
         <translation>Action incorrecte</translation>
     </message>
@@ -69,13 +83,13 @@
 <context>
     <name>Actions::ClickInstance</name>
     <message>
-        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="54"/>
+        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="55"/>
         <source>Invalid click amount</source>
         <translation>Quantité de clics incorrecte</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="66"/>
-        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="74"/>
+        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="68"/>
+        <location filename="../actions/actionpackdevice/actions/clickinstance.cpp" line="76"/>
         <source>Unable to emulate click: button event failed</source>
         <translation>Impossible de simuler un clic : l&apos;évènement de bouton n&apos;a pas pu être envoyé</translation>
     </message>
@@ -83,15 +97,25 @@
 <context>
     <name>Actions::CursorPathDefinition</name>
     <message>
-        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="44"/>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="45"/>
         <source>Path</source>
         <translation>Trajet</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="45"/>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="46"/>
         <source>The path to follow</source>
         <translation>Le trajet à effectuer</translation>
     </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="49"/>
+        <source>Offset</source>
+        <translation>Décalage</translation>
+    </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="50"/>
+        <source>The offset to apply to the path</source>
+        <translation>Le décalage à appliquer aux points du chemin</translation>
+    </message>
 </context>
 <context>
     <name>Actions::KeyDefinition</name>
@@ -233,6 +257,16 @@
         <source>The position where to move the cursor</source>
         <translation>La position où déplacer le curseur</translation>
     </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="48"/>
+        <source>Offset</source>
+        <translation>Décalage</translation>
+    </message>
+    <message>
+        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="49"/>
+        <source>The offset to apply to the cursor movement</source>
+        <translation>Le décalage à appliquer au mouvement du pointeur de la souris</translation>
+    </message>
 </context>
 <context>
     <name>Actions::TextDefinition</name>
@@ -416,12 +450,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="85"/>
+        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="89"/>
         <source>Click</source>
         <translation>Clic</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="88"/>
+        <location filename="../actions/actionpackdevice/actions/clickdefinition.h" line="92"/>
         <source>Emulates a mouse click</source>
         <translation>Simule un clic de souris</translation>
     </message>
@@ -436,12 +470,12 @@
         <translation>Simule la pression d&apos;une touche</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="49"/>
+        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="53"/>
         <source>Move cursor</source>
         <translation>Déplacement du curseur</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="52"/>
+        <location filename="../actions/actionpackdevice/actions/movecursordefinition.h" line="56"/>
         <source>Move the mouse cursor</source>
         <translation>Déplace le curseur de souris</translation>
     </message>
@@ -498,12 +532,12 @@
         <translation type="obsolete">Pression et relâchement</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="49"/>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="54"/>
         <source>Cursor path</source>
         <translation>Trajet du curseur</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="52"/>
+        <location filename="../actions/actionpackdevice/actions/cursorpathdefinition.h" line="57"/>
         <source>Move the mouse cursor on a path</source>
         <translation>Déplace le curseur de la souris sur un trajet</translation>
     </message>
